<?php # $Id: lang_de.inc.php 2093 2008-01-18 12:50:00Z garvinhicking $

@define('PLUGIN_EVENT_TEXTILE_NAME',     'Textformatierung: Textile');
@define('PLUGIN_EVENT_TEXTILE_DESC',     'Textile-Formatierung durchfhren');
@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', '<a href="%s">Textile</a>-Formatierung erlaubt');
@define('PLUGIN_EVENT_TEXTILE_VERSION', 'Textile-Version');
@define('PLUGIN_EVENT_TEXTILE_VERSION_DESCRIPTION', 'Welche Version von Textile soll verwendet werden?');

